/* 
 * Copyright (C) 2001-2012 Michael Fuchs
 *
 * This file is part of herold.
 * 
 * herold is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * herold is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with herold.  If not, see <http://www.gnu.org/licenses/>.  
 */
package org.dbdoclet.trafo.tag.html;

import java.util.HashMap;

public class Meta extends ReplaceElement {

	private static final String tag = "meta";
	private static HashMap<String, HashMap<String, String>> validParentMap;

	static {

		validParentMap = new HashMap<String, HashMap<String, String>>();
		validParentMap.put(Head.getTag(), HtmlElement.getAttributeMap());
	}

	public Meta() {

		setNodeName("meta");
		setFormatType(FORMAT_CONTENT);
		isEmpty(true);
	}

	public static String getTag() {
		return tag;
	}

	@Override
	public boolean validate() {

		if (validate(validParentMap)) {
			return true;
		}

		return false;
	}

	public String getName() {
		return getAttribute("name");
	}

	public String getContent() {
		return getAttribute("content");
	}
}
